@@ -1140,7 +1140,7 @@ PROT_UrlCryptoKeyManager.prototype.hasKey = function() {
 
 PROT_UrlCryptoKeyManager.prototype.unUrlSafe = function(key)
 {
-    return key ? key.replace("-", "+").replace("_", "/") : "";
+    return key ? key.replace(/-/g, "+").replace(/_/g, "/") : "";
 }
 
 /**
@@ -1419,25 +1419,13 @@ PROT_XMLFetcher.prototype = {
       fetcher._callback(responseText, status);
   },
 
-  // Suppress any certificate errors
-  notifyCertProblem: function(socketInfo, status, targetSite) {
-    return true;
-  },
-
-  // Suppress any ssl errors
-  notifySSLError: function(socketInfo, error, targetSite) {
-    return true;
-  },
-
   // nsIInterfaceRequestor
   getInterface: function(iid) {
     return this.QueryInterface(iid);
   },
 
   QueryInterface: function(iid) {
-    if (!iid.equals(Components.interfaces.nsIBadCertListener2) &&
-        !iid.equals(Components.interfaces.nsISSLErrorListener) &&
-        !iid.equals(Components.interfaces.nsIInterfaceRequestor) &&
+    if (!iid.equals(Components.interfaces.nsIInterfaceRequestor) &&
         !iid.equals(Components.interfaces.nsISupports))
       throw Components.results.NS_ERROR_NO_INTERFACE;
     return this;
