@@ -3,7 +3,7 @@
 pref("toolkit.defaultChromeURI", "chrome://bluegriffon/content/xul/bluegriffon.xul");
 pref("browser.chromeURL", "chrome://bluegriffon/content/xul/bluegriffon.xul");
 pref("browser.hiddenWindowChromeURL", "chrome://bluegriffon/content/xul/hiddenWindow.xul");
-pref("toolkit.singletonWindowType", "hidden-main");
+pref("toolkit.singletonWindowType", "bluegriffon");
 pref("bluegriffon.singletonWindowType", "bluegriffon");
 
 // mandatory for XULrunner apps
@@ -21,7 +21,7 @@ pref("javascript.options.strict", false);
 pref("nglayout.debug.disable_xul_cache", true);
 pref("nglayout.debug.disable_xul_fastload", true);
 
-pref("general.useragent.extra.mybrowser", "bluegriffon/1.7");
+pref("general.useragent.extra.mybrowser", "bluegriffon/1.7.1");
 pref("intl.locale.matchOS", true);
 pref("intl.accept_charsets", "iso-8859-1,*,utf-8");
 pref("browser.display.use_document_fonts", 1);
